@@ -304,7 +304,7 @@ QVariant PropertyMapItem::data(int column, int role) const
         return toolTip(column);
     case Qt::DisplayRole:
     case TreeModel::SortRole: // fallthrough, since SortRole should default to DisplayRole
-        return property(_propertyOrder[column].toAscii());
+        return property(_propertyOrder[column].toLatin1());
     default:
         return QVariant();
     }
@@ -317,7 +317,7 @@ bool PropertyMapItem::setData(int column, const QVariant &value, int role)
         return false;
 
     emit dataChanged(column);
-    return setProperty(_propertyOrder[column].toAscii(), value);
+    return setProperty(_propertyOrder[column].toLatin1(), value);
 }
 
 
@@ -554,7 +554,9 @@ void TreeModel::endAppendChilds()
     }
     Q_ASSERT(_aboutToRemoveOrInsert);
     ChildStatus cs = _childStatus;
+#ifndef QT_NO_DEBUG
     QModelIndex parent = indexByItem(parentItem);
+#endif
     Q_ASSERT(cs.parent == parent);
     Q_ASSERT(rowCount(parent) == cs.childCount + cs.end - cs.start + 1);
 
@@ -600,8 +602,10 @@ void TreeModel::endRemoveChilds()
 
     // concistency checks
     Q_ASSERT(_aboutToRemoveOrInsert);
+#ifndef QT_NO_DEBUG
     ChildStatus cs = _childStatus;
     QModelIndex parent = indexByItem(parentItem);
+#endif
     Q_ASSERT(cs.parent == parent);
     Q_ASSERT(rowCount(parent) == cs.childCount - cs.end + cs.start - 1);
     _aboutToRemoveOrInsert = false;
