@@ -828,9 +828,9 @@ QList<NetworkInfo> SqliteStorage::networks(UserId user)
                 net.networkId = networksQuery.value(0).toInt();
                 net.networkName = networksQuery.value(1).toString();
                 net.identity = networksQuery.value(2).toInt();
-                net.codecForServer = networksQuery.value(3).toString().toAscii();
-                net.codecForEncoding = networksQuery.value(4).toString().toAscii();
-                net.codecForDecoding = networksQuery.value(5).toString().toAscii();
+                net.codecForServer = networksQuery.value(3).toString().toLatin1();
+                net.codecForEncoding = networksQuery.value(4).toString().toLatin1();
+                net.codecForDecoding = networksQuery.value(5).toString().toLatin1();
                 net.useRandomServer = networksQuery.value(6).toInt() == 1 ? true : false;
                 net.perform = networksQuery.value(7).toString().split("\n");
                 net.useAutoIdentify = networksQuery.value(8).toInt() == 1 ? true : false;
@@ -1110,7 +1110,7 @@ BufferInfo SqliteStorage::bufferInfo(UserId user, const NetworkId &networkId, Bu
                 qCritical() << "  bound Values:";
                 QList<QVariant> list = query.boundValues().values();
                 for (int i = 0; i < list.size(); ++i)
-                    qCritical() << i << ":" << list.at(i).toString().toAscii().data();
+                    qCritical() << i << ":" << list.at(i).toString().toLatin1().data();
                 Q_ASSERT(false);
             }
         }
